<?php
/**
 * Woodworker: Customizer
 *
 * @subpackage Woodworker
 * @since 1.0
 */

use WPTRT\Customize\Section\Luzuk_Woodworker_Button;

add_action( 'customize_register', function( $manager ) {

	$manager->register_section_type( Luzuk_Woodworker_Button::class );

	$manager->add_section(
		new Luzuk_Woodworker_Button( $manager, 'luzuk_woodworker_pro', [
			'title' => __( 'Woodworker Pro', 'woodworker' ),
			'priority' => 0,
			'button_text' => __( 'Go Pro', 'woodworker' ),
			'button_url'  => esc_url( 'https://www.luzuk.com/product/premium-woodworker-wp-theme/', 'woodworker')
		] )
	);

} );


// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

	$version = wp_get_theme()->get( 'Version' );

	wp_enqueue_script(
		'woodworker-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
		[ 'customize-controls' ],
		$version,
		true
	);

	wp_enqueue_style(
		'woodworker-customize-section-button',
		get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
		[ 'customize-controls' ],
 		$version
	);

} );

function luzuk_woodworker_customize_register( $wp_customize ) {

	$wp_customize->add_setting('luzuk_woodworker_logo_size',array(
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_float'
	));
	$wp_customize->add_control('luzuk_woodworker_logo_size',array(
		'type' => 'range',
		'label' => __('Logo Size','woodworker'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('luzuk_woodworker_logo_padding',array(
		'sanitize_callback'	=> 'esc_html'
	));
	$wp_customize->add_control('luzuk_woodworker_logo_padding',array(
		'label' => __('Logo Margin','woodworker'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting('luzuk_woodworker_logo_top_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_float'
	));
	$wp_customize->add_control('luzuk_woodworker_logo_top_padding',array(
		'type' => 'number',
		'description' => __('Top','woodworker'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_woodworker_logo_bottom_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_float'
	));
	$wp_customize->add_control('luzuk_woodworker_logo_bottom_padding',array(
		'type' => 'number',
		'description' => __('Bottom','woodworker'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_woodworker_logo_left_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_float'
	));
	$wp_customize->add_control('luzuk_woodworker_logo_left_padding',array(
		'type' => 'number',
		'description' => __('Left','woodworker'),
		'section' => 'title_tagline',
	));

	$wp_customize->add_setting('luzuk_woodworker_logo_right_padding',array(
		'default' => '',
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_float'
 	));
 	$wp_customize->add_control('luzuk_woodworker_logo_right_padding',array(
		'type' => 'number',
		'description' => __('Right','woodworker'),
		'section' => 'title_tagline',
    ));

	$wp_customize->add_setting('luzuk_woodworker_show_site_title',array(
		'default' => true,
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_woodworker_show_site_title',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Title','woodworker'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting( 'luzuk_woodworker_site_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_site_title_color', array(
		'label' => 'Title Color',
		'section' => 'title_tagline',
	)));

	$wp_customize->add_setting('luzuk_woodworker_show_tagline',array(
		'default' => true,
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_checkbox'
	));
	$wp_customize->add_control('luzuk_woodworker_show_tagline',array(
		'type' => 'checkbox',
		'label' => __('Show / Hide Site Tagline','woodworker'),
		'section' => 'title_tagline'
	));

	$wp_customize->add_setting( 'luzuk_woodworker_site_tagline_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_site_tagline_color', array(
		'label' => 'Tagline Color',
		'section' => 'title_tagline',
	)));

	$wp_customize->add_panel( 'luzuk_woodworker_panel_id', array(
		'priority' => 10,
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => __( 'Theme Settings', 'woodworker' ),
		'description' => __( 'Description of what this panel does.', 'woodworker' ),
	) );

	$wp_customize->add_section( 'luzuk_woodworker_theme_options_section', array(
    	'title'      => __( 'General Settings', 'woodworker' ),
		'priority'   => 30,
		'panel' => 'luzuk_woodworker_panel_id'
	) );

	$wp_customize->add_setting('luzuk_woodworker_theme_options',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_woodworker_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_woodworker_theme_options',array(
		'type' => 'select',
		'label' => __('Blog Page Sidebar Layout','woodworker'),
		'section' => 'luzuk_woodworker_theme_options_section',
		'choices' => array(
		   'Left Sidebar' => __('Left Sidebar','woodworker'),
		   'Right Sidebar' => __('Right Sidebar','woodworker'),
		   'One Column' => __('One Column','woodworker')
		),
	));

	$wp_customize->add_setting('luzuk_woodworker_single_post_sidebar',array(
		'default' => 'Right Sidebar',
		'sanitize_callback' => 'luzuk_woodworker_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_woodworker_single_post_sidebar',array(
        'type' => 'select',
        'label' => __('Single Post Sidebar Layout','woodworker'),
        'section' => 'luzuk_woodworker_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','woodworker'),
            'Right Sidebar' => __('Right Sidebar','woodworker'),
            'One Column' => __('One Column','woodworker')
        ),
	));

	$wp_customize->add_setting('luzuk_woodworker_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_woodworker_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_woodworker_page_sidebar',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','woodworker'),
        'section' => 'luzuk_woodworker_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','woodworker'),
            'Right Sidebar' => __('Right Sidebar','woodworker'),
            'One Column' => __('One Column','woodworker')
        ),
	));

	$wp_customize->add_setting('luzuk_woodworker_archive_page_sidebar',array(
		'default' => 'One Column',
		'sanitize_callback' => 'luzuk_woodworker_sanitize_choices'
	));
	$wp_customize->add_control('luzuk_woodworker_archive_page_sidebar',array(
        'type' => 'select',
        'label' => __('Archive & Search Page Sidebar Layout','woodworker'),
        'section' => 'luzuk_woodworker_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','woodworker'),
            'Right Sidebar' => __('Right Sidebar','woodworker'),
            'One Column' => __('One Column','woodworker')
        ),
	));

	$wp_customize->add_setting( 'luzuk_woodworker_boxfull_width', array(
		'default'           => 'Full Width',
		'sanitize_callback' => 'luzuk_woodworker_sanitize_choices'
	));
	
	$wp_customize->add_control( 'luzuk_woodworker_boxfull_width', array(
		'label'    => __( 'Section Width', 'woodworker' ),
		'section'  => 'luzuk_woodworker_theme_options_section',
		'type'     => 'select',
		'choices'  => array(
			'container'  => __('Box Width', 'woodworker'),
			'container-fluid' => __('Full Width', 'woodworker'),
			'none' => __('None', 'woodworker')
		),
	));

	
 
	//Header
	$wp_customize->add_section( 'luzuk_woodworker_header' , array(
    	'title'    => __( 'Header Settings', 'woodworker' ),
		'priority' => null,
		'panel' => 'luzuk_woodworker_panel_id'
	) );

	$wp_customize->add_setting('luzuk_woodworker_header_mail',array(
		'default' => 'Info1234@Gmail.Com',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_header_mail',array(
	   	'type' => 'text',
	   	'label' => __('Mail Text','woodworker'),
	   	'section' => 'luzuk_woodworker_header',
	));


	$wp_customize->add_setting('luzuk_woodworker_header_phoneno',array(
		'default' => '(00) 123-456-789',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_header_phoneno',array(
	   	'type' => 'text',
	   	'label' => __('Phone Number','woodworker'),
	   	'section' => 'luzuk_woodworker_header',
	));

	$wp_customize->add_setting('luzuk_woodworker_heade_address',array(
		'default' => '3261 Anmoore Lorem Ipsum , NY 11230',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_heade_address',array(
	   	'type' => 'text',
	   	'label' => __('Address','woodworker'),
	   	'section' => 'luzuk_woodworker_header',
	));

	$wp_customize->add_setting('luzuk_woodworker_twitterlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_woodworker_twitterlink',array(
	   	'type' => 'url',
	   	'label' => __('Twitter Icon Link','woodworker'),
	   	'section' => 'luzuk_woodworker_header',
	));

	$wp_customize->add_setting('luzuk_woodworker_instalink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_woodworker_instalink',array(
	   	'type' => 'url',
	   	'label' => __('Instagram Icon Link','woodworker'),
	   	'section' => 'luzuk_woodworker_header',
	));


	$wp_customize->add_setting('luzuk_woodworker_linkedinlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_woodworker_linkedinlink',array(
	   	'type' => 'url',
	   	'label' => __('Linkedin Icon Link','woodworker'),
	   	'section' => 'luzuk_woodworker_header',
	));

	$wp_customize->add_setting('luzuk_woodworker_fblink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_woodworker_fblink',array(
	   	'type' => 'url',
	   	'label' => __('Facebook Icon Link','woodworker'),
	   	'section' => 'luzuk_woodworker_header',
	));


	$wp_customize->add_setting( 'luzuk_woodworker_headertopbg_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headertopbg_col', array(
		'label' => 'Top Head BG Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headerbottombg_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headerbottombg_col', array(
		'label' => 'Bottom Head BG Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headertophedtext_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headertophedtext_col', array(
		'label' => 'Top Head Text Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headertophedicons_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headertophedicons_col', array(
		'label' => 'Top Head Icons Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headertophediconshrv_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headertophediconshrv_col', array(
		'label' => 'Top Head Text Hover Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headertophedsocialicon_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headertophedsocialicon_col', array(
		'label' => 'Top Head Social Icons Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headertophedsocialiconhrv_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headertophedsocialiconhrv_col', array(
		'label' => 'Top Head Social Icons Hover Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_brd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_brd_color', array(
		'label' => 'Border Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_menu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_menu_color', array(
		'label' => 'Menu Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_menudash_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_menudash_color', array(
		'label' => 'Menu Dash Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_menuhover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_menuhover_color', array(
		'label' => 'Menu Hover Color',
		'section' => 'luzuk_woodworker_header',
	)));


	$wp_customize->add_setting( 'luzuk_woodworker_submenu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_submenu_color', array(
		'label' => 'Submenu Text Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_submenubg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_submenubg_color', array(
		'label' => 'Submenu BG Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headersearchicon_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headersearchicon_col', array(
		'label' => 'Search Icon Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headersearchbrd_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headersearchbrd_col', array(
		'label' => 'Search Form Border Color',
		'section' => 'luzuk_woodworker_header',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_headersearchplaceholder_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headersearchplaceholder_col', array(
		'label' => 'Search Form Placeholder Color',
		'section' => 'luzuk_woodworker_header',
	)));
	
	

	$wp_customize->add_setting( 'luzuk_woodworker_headersearchformbg_col', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_headersearchformbg_col', array(
		'label' => 'Search Form BG Color',
		'section' => 'luzuk_woodworker_header',
	)));

	
	// banner Section
	$wp_customize->add_section('luzuk_woodworker_banner_section',array(
		'title'	=> __('Banner Settings','woodworker'),
		'panel' => 'luzuk_woodworker_panel_id',
	));

	$wp_customize->add_setting(
    	'luzuk_woodworker_banner_image',
	    array(
	        'sanitize_callback' => 'esc_url_raw'
	    )
	);
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'luzuk_woodworker_banner_image',
	        array(
			    'label'   		=> __('Image','woodworker'),
				'description'   		=> __('Image size 1500*747','woodworker'),
	            'section' => 'luzuk_woodworker_banner_section',
	            'settings' => 'luzuk_woodworker_banner_image',
	        )
	    )
	);

	$wp_customize->add_setting('luzuk_woodworker_bannersubheading',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_bannersubheading',array(
	   	'type' => 'text',
	   	'label' => __('Sub Heading','woodworker'),
	   	'section' => 'luzuk_woodworker_banner_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_bannersubheading_font_size',array(
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_float'
	));
	$wp_customize->add_control('luzuk_woodworker_bannersubheading_font_size',array(
		'type' => 'number',
		'label' => __('Font Size','woodworker'),
		'section' => 'luzuk_woodworker_banner_section'
	));

	$wp_customize->add_setting('luzuk_woodworker_bannerheading',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_bannerheading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','woodworker'),
	   	'section' => 'luzuk_woodworker_banner_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_bannerheading_font_size',array(
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_float'
	));
	$wp_customize->add_control('luzuk_woodworker_bannerheading_font_size',array(
		'type' => 'number',
		'label' => __('Font Size','woodworker'),
		'section' => 'luzuk_woodworker_banner_section'
	));

	$wp_customize->add_setting('luzuk_woodworker_bannerdescription',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_bannerdescription',array(
	   	'type' => 'text',
	   	'label' => __('Description','woodworker'),
	   	'section' => 'luzuk_woodworker_banner_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_bannerdescription_font_size',array(
		'sanitize_callback'	=> 'luzuk_woodworker_sanitize_float'
	));
	$wp_customize->add_control('luzuk_woodworker_bannerdescription_font_size',array(
		'type' => 'number',
		'label' => __('Font Size','woodworker'),
		'section' => 'luzuk_woodworker_banner_section'
	));

	$wp_customize->add_setting('luzuk_woodworker_bannerreadmorebtnlink',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_bannerreadmorebtnlink',array(
	   	'type' => 'text',
	   	'label' => __('Button Link','woodworker'),
	   	'section' => 'luzuk_woodworker_banner_section',
	));

	$wp_customize->add_setting('bann_maintitle',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('bann_maintitle',array(
	   	'type' => 'text',
	   	'label' => __('Form Title','woodworker'),
	   	'section' => 'luzuk_woodworker_banner_section',
	));

	$wp_customize->add_setting('bann_fm_shortcode',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('bann_fm_shortcode',array(
	   	'type' => 'text',
	   	'label' => __('Add Form shortcode','woodworker'),
	   	'section' => 'luzuk_woodworker_banner_section',
	));

	$wp_customize->add_setting( 'luzuk_woodworker_bannersubheadingbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannersubheadingbrd_color', array(
		'label' => 'Icon Border Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannersubheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannersubheading_color', array(
		'label' => 'SubHeading Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	
	$wp_customize->add_setting( 'luzuk_woodworker_bannerheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerheading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerdescription_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerdescription_color', array(
		'label' => 'Description Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerbtntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerbtntext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerbtnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerbtnbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerbtnbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerbtnbrd_color', array(
		'label' => 'Button Border Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerbtntexthover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerbtntexthover_color', array(
		'label' => 'Button Text Hover Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerformtitle_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerformtitle_color', array(
		'label' => 'Form Title Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerformbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerformbg_color', array(
		'label' => 'Form BG Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerformbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerformbrd_color', array(
		'label' => 'Form Border Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerformfieldtitle_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerformfieldtitle_color', array(
		'label' => 'Form Field Title Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerformbtntext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerformbtntext_color', array(
		'label' => 'Form Button Text Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_bannerformbtnbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_bannerformbtnbg_color', array(
		'label' => 'Form Button BG Color',
		'section' => 'luzuk_woodworker_banner_section',
	)));


	
	// aboutus Section
	$wp_customize->add_section('luzuk_woodworker_aboutus_section',array(
		'title'	=> __('Aboutus Settings','woodworker'),
		'description'=> __('<b>Note :</b> This section will appear below the Banner.','woodworker'),
		'panel' => 'luzuk_woodworker_panel_id',
	));

	$wp_customize->add_setting(
    	'luzuk_woodworker_aboutus_image',
	    array(
	        'sanitize_callback' => 'esc_url_raw'
	    )
	);
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'luzuk_woodworker_aboutus_image',
	        array(
			    'label'   		=> __('Image','woodworker'),
				'description'   		=> __('Image size 510*768','woodworker'),
	            'section' => 'luzuk_woodworker_aboutus_section',
	            'settings' => 'luzuk_woodworker_aboutus_image',
	        )
	    )
	);

	$wp_customize->add_setting('luzuk_woodworker_aboutussubheading',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutussubheading',array(
	   	'type' => 'text',
	   	'label' => __('Sub Heading','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_aboutusheading',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutusheading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_aboutustitle',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutustitle',array(
	   	'type' => 'text',
	   	'label' => __('Title','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_aboutusdescription',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutusdescription',array(
	   	'type' => 'text',
	   	'label' => __('Description','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting(
    	'luzuk_woodworker_aboutus_profileimg',
	    array(
	        'sanitize_callback' => 'esc_url_raw'
	    )
	);
	$wp_customize->add_control(
	    new WP_Customize_Image_Control(
	        $wp_customize,
	        'luzuk_woodworker_aboutus_profileimg',
	        array(
			    'label'   		=> __('Profile Image','woodworker'),
				'description'   		=> __('Image size 100*100','woodworker'),
	            'section' => 'luzuk_woodworker_aboutus_section',
	            'settings' => 'luzuk_woodworker_aboutus_profileimg',
	        )
	    )
	);

	$wp_customize->add_setting('luzuk_woodworker_aboutusname',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutusname',array(
	   	'type' => 'text',
	   	'label' => __('Name','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_aboutusdesignation',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutusdesignation',array(
	   	'type' => 'text',
	   	'label' => __('Designation','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_aboutuslist1',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutuslist1',array(
	   	'type' => 'text',
	   	'label' => __('List 1','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_aboutuslist2',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutuslist2',array(
	   	'type' => 'text',
	   	'label' => __('List 2','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_aboutuslist3',array(
		'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_aboutuslist3',array(
	   	'type' => 'text',
	   	'label' => __('List 3','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	$wp_customize->add_setting('luzuk_woodworker_aboutusreadmorebtnlink',array(
    	'default' => '#',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('luzuk_woodworker_aboutusreadmorebtnlink',array(
	   	'type' => 'url',
	   	'label' => __('Read More Button Link','woodworker'),
	   	'section' => 'luzuk_woodworker_aboutus_section',
	));

	
	$wp_customize->add_setting( 'luzuk_woodworker_aboutussubheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutussubheading_color', array(
		'label' => 'SubHeading Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutussubheadingbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutussubheadingbrd_color', array(
		'label' => 'SubHeading Border Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusheading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusheading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutustitle_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutustitle_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusdescription_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusdescription_color', array(
		'label' => 'Description Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusprofilename_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusprofilename_color', array(
		'label' => 'Profile Name Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusprofiledesignation_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusprofiledesignation_color', array(
		'label' => 'Profile Designation Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusprofilebg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusprofilebg_color', array(
		'label' => 'Profile BG Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusprofilebrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusprofilebrd_color', array(
		'label' => 'Profile Border Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutuslisticon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutuslisticon_color', array(
		'label' => 'Lists Icon Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));
	
	$wp_customize->add_setting( 'luzuk_woodworker_aboutuslists_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutuslists_color', array(
		'label' => 'Lists Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	
	$wp_customize->add_setting( 'luzuk_woodworker_aboutusgetstartedtext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusgetstartedtext_color', array(
		'label' => 'Button Text Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusgetstartedbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusgetstartedbg_color', array(
		'label' => 'Button BG Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusgetstartedtexthover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusgetstartedtexthover_color', array(
		'label' => 'Button Text Hover Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_aboutusimgbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_aboutusimgbrd_color', array(
		'label' => 'Image Border Color',
		'section' => 'luzuk_woodworker_aboutus_section',
	)));
	

	// services Section
	$wp_customize->add_section('luzuk_woodworker_services_section',array(
		'title'	=> __('Services Settings','woodworker'),
		'description'=> __('<b>Note :</b> This section will appear below the Aboutus.','woodworker'),
		'panel' => 'luzuk_woodworker_panel_id',
	));


	$wp_customize->add_setting('luzuk_woodworker_servicesheading',array(
    	'default' => '',
    	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('luzuk_woodworker_servicesheading',array(
	   	'type' => 'text',
	   	'label' => __('Heading','woodworker'),
	   	'section' => 'luzuk_woodworker_services_section',
	));

	$pages = get_pages(); // Retrieve pages
	$page_options = array(); // Initialize page options array
	foreach ($pages as $page) {
		$page_options[$page->ID] = $page->post_title; // Store page ID and title in options array
	}

	$wp_customize->add_setting('luzuk_woodworker_page_setting_1', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_woodworker_page_setting_1', array(
		'label'    => __('Select Page 1', 'woodworker'),
		'section'  => 'luzuk_woodworker_services_section', 
		'type'     => 'dropdown-pages',
	));



	$wp_customize->add_setting('luzuk_woodworker_page_setting_2', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_woodworker_page_setting_2', array(
		'label'    => __('Select Page 2', 'woodworker'),
		'section'  => 'luzuk_woodworker_services_section', 
		'type'     => 'dropdown-pages',
	));


	$wp_customize->add_setting('luzuk_woodworker_page_setting_3', array(
		'default'            => '',
		'sanitize_callback'  => 'absint', // Use absint to ensure the value is an integer
	));

	$wp_customize->add_control('luzuk_woodworker_page_setting_3', array(
		'label'    => __('Select Page 3', 'woodworker'),
		'section'  => 'luzuk_woodworker_services_section', 
		'type'     => 'dropdown-pages',
	));

	
	$wp_customize->add_setting( 'luzuk_woodworker_services_heading_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_services_heading_color', array(
		'label' => 'Heading Color',
		'section' => 'luzuk_woodworker_services_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_services_headbrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_services_headbrd_color', array(
		'label' => 'Heading Border Color',
		'section' => 'luzuk_woodworker_services_section',
	)));


	$wp_customize->add_setting( 'luzuk_woodworker_services_title_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_services_title_color', array(
		'label' => 'Title Color',
		'section' => 'luzuk_woodworker_services_section',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_services_titlebrd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_services_titlebrd_color', array(
		'label' => 'Title BG Color',
		'section' => 'luzuk_woodworker_services_section',
	)));


	$wp_customize->add_setting( 'luzuk_woodworker_services_brd_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_services_brd_color', array(
		'label' => 'Border Color',
		'section' => 'luzuk_woodworker_services_section',
	)));


	

	//Footer
    $wp_customize->add_section( 'luzuk_woodworker_footer', array(
    	'title'  => __( 'Footer Settings', 'woodworker' ),
		'priority' => null,
		'panel' => 'luzuk_woodworker_panel_id'
	) );

	$wp_customize->add_setting('luzuk_woodworker_show_back_totop',array(
       'default' => true,
       'sanitize_callback'	=> 'luzuk_woodworker_sanitize_checkbox'
    ));
    $wp_customize->add_control('luzuk_woodworker_show_back_totop',array(
       'type' => 'checkbox',
       'label' => __('Show / Hide Back to Top','woodworker'),
       'section' => 'luzuk_woodworker_footer'
    ));

    $wp_customize->add_setting('luzuk_woodworker_footer_copy',array(
		'default' => 'Woodworker WordPress Theme By Luzuk',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('luzuk_woodworker_footer_copy',array(
		'label'	=> __('Copyright Text','woodworker'),
		'section' => 'luzuk_woodworker_footer',
		'setting' => 'luzuk_woodworker_footer_copy',
		'type' => 'text'
	));

	$wp_customize->add_setting( 'luzuk_woodworker_footertext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footertext_color', array(
		'label' => 'Text Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footericon_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footericon_color', array(
		'label' => 'Icon Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footeractivemenu_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footeractivemenu_color', array(
		'label' => 'Active Menu Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footerbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footerbg_color', array(
		'label' => 'BG Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footercopyright_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footercopyright_color', array(
		'label' => 'Copyright Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footercopyrightinnerbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footercopyrightinnerbg_color', array(
		'label' => 'Inner BG Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footerscrolltotoptext_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footerscrolltotoptext_color', array(
		'label' => 'Scroll To Top Text Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footerscrolltotopbg_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footerscrolltotopbg_color', array(
		'label' => 'Scroll To Top BG Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footerscrolltotoptexthover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footerscrolltotoptexthover_color', array(
		'label' => 'Scroll To Top Text Hover Color',
		'section' => 'luzuk_woodworker_footer',
	)));

	$wp_customize->add_setting( 'luzuk_woodworker_footerscrolltotophover_color', array(
		'default' => '',
		'sanitize_callback' => 'sanitize_hex_color'
	));
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'luzuk_woodworker_footerscrolltotophover_color', array(
		'label' => 'Scroll To Top Hover Color',
		'section' => 'luzuk_woodworker_footer',
	)));




	

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'luzuk_woodworker_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'luzuk_woodworker_customize_partial_blogdescription',
	) );
}
add_action( 'customize_register', 'luzuk_woodworker_customize_register' );

function luzuk_woodworker_customize_partial_blogname() {
	bloginfo( 'name' );
}

function luzuk_woodworker_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

if (class_exists('WP_Customize_Control')) {

   	class Luzuk_Woodworker_Fontawesome_Icon_Chooser extends WP_Customize_Control {

      	public $type = 'icon';

      	public function render_content() { ?>
	     	<label>
	            <span class="customize-control-title">
	               <?php echo esc_html($this->label); ?>
	            </span>

	            <?php if ($this->description) { ?>
	                <span class="description customize-control-description">
	                   <?php echo wp_kses_post($this->description); ?>
	                </span>
	            <?php } ?>

	            <div class="woodworker-selected-icon">
	                <i class="fa <?php echo esc_attr($this->value()); ?>"></i>
	                <span><i class="fa fa-angle-down"></i></span>
	            </div>

	            <ul class="woodworker-icon-list clearfix">
	                <?php
	                $luzuk_woodworker_font_awesome_icon_array = luzuk_woodworker_font_awesome_icon_array();
	                foreach ($luzuk_woodworker_font_awesome_icon_array as $luzuk_woodworker_font_awesome_icon) {
	                   $icon_class = $this->value() == $luzuk_woodworker_font_awesome_icon ? 'icon-active' : '';
	                   echo '<li class=' . esc_attr($icon_class) . '><i class="' . esc_attr($luzuk_woodworker_font_awesome_icon) . '"></i></li>';
	                }
	                ?>
	            </ul>
	            <input type="hidden" value="<?php $this->value(); ?>" <?php $this->link(); ?> />
	        </label>
	        <?php
      	}
  	}
}
function luzuk_woodworker_customizer_script() {
   wp_enqueue_style( 'font-awesome-1', esc_url(get_template_directory_uri()).'/assets/css/fontawesome-all.css');
}
add_action( 'customize_controls_enqueue_scripts', 'luzuk_woodworker_customizer_script' );